Imports System.IO
Imports System.Xml
Imports System.Data
Imports System.Data.SqlClient
Imports Microsoft.AnalysisServices.AdomdClient

Public Class Main

    Private m_sessionID As String


    ''' <summary>
    ''' Connects to the specified SSAS database
    ''' </summary>
    ''' <remarks></remarks>
    Private ReadOnly Property Connect() As AdomdConnection

        Get
            Dim connection As AdomdConnection

            Try
Connect:
                ' Try to reuse the existing session
                connection = New AdomdConnection(Me.txtConnectionString.Text)
                connection.SessionID = m_sessionID
                connection.Open()
                m_sessionID = connection.SessionID      ' Cache the session ID
                Return connection

            Catch ex As AdomdConnectionException
                If (ex.InnerException Is Nothing) = False Then
                    ' Session not found error
                    If ex.InnerException.Message.Contains(m_sessionID) Then
                        m_sessionID = Nothing
                        ' Try again with no session
                        GoTo Connect
                        grpQuery.Enabled = True
                    Else
                        Throw ex
                    End If
                End If

            Catch ex As Exception
                Throw ex
            Finally
                Me.Cursor = Cursors.Default
            End Try
        End Get
    End Property

    ''' <summary>
    ''' Determines the user selection
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub DoSelection(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles radOpenQuery.CheckedChanged, radSingleton.CheckedChanged, _
        radRowset.CheckedChanged, radSessionModel.CheckedChanged, radLocalModel.CheckedChanged

        txtQuery.Text = My.Resources.WinDataMiner.ResourceManager.GetString(CType(sender, RadioButton).Name)
        dgvResults.DataSource = Nothing
        dgvResults.Refresh()
        btnSend.Enabled = True


    End Sub
    ''' <summary>
    ''' Executes an OPENQUERY DMX Statement
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub DoOpenQuery()
        Dim connection As AdomdConnection = Me.Connect
        Dim command As New AdomdCommand(txtQuery.Text, connection)
        Dim adapter As New AdomdDataAdapter(command)
        Dim dataset As New DataSet

        ' Fill the dataset
        adapter.Fill(dataset)

        ' Bind to grid
        dgvResults.DataSource = dataset.Tables(0)
        connection.Close(False)
    End Sub

    ''' <summary>
    ''' Executes a singleton DMX Statement
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub DoSingleton()
        Dim connection As AdomdConnection = Me.Connect
        Dim command As New AdomdCommand(txtQuery.Text, connection)
        Dim adapter As New AdomdDataAdapter(command)
        Dim dataset As New DataSet

        command.Parameters.Add("FirstName", "John")
        command.Parameters.Add("Age", 40)
        command.Parameters.Add("CommuteDistance", "5-10 Miles")
        command.Parameters.Add("HouseOwnerFlag", 1)
        command.Parameters.Add("NumberCarsOwned", 2)
        command.Parameters.Add("NumberChildren", 3)
        command.Parameters.Add("Occupation", "Management")
        command.Parameters.Add("YearlyIncome", 90000)

        ' Fill the dataset
        adapter.Fill(dataset)

        ' Bind to grid
        dgvResults.DataSource = dataset.Tables(0)
        connection.Close(False)
    End Sub
    ''' <summary>
    ''' Executes a rowset DMX Statement
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub DoRowset()
        Dim connection As AdomdConnection = Me.Connect
        Dim command As New AdomdCommand(txtQuery.Text, connection)
        Dim adapter As New AdomdDataAdapter(command)
        Dim dataset As New DataSet

        Dim input As DataSet = GetData()

        command.Parameters.Add("InputTable", input.Tables(0))

        ' Fill the dataset
        adapter.Fill(dataset)

        ' Bind to grid
        dgvResults.DataSource = dataset.Tables(0)
        connection.Close(False)
    End Sub
    ''' <summary>
    ''' A  helper function to return a dataset from the DMX query
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Private Function GetData() As DataSet

        Dim connection As New SqlConnection("Initial Catalog=AdventureWorksDW;Data Source=localhost;Integrated Security=SSPI;")

        ' Parse the query text to retrieve the SELECT statement only
        Dim selectQuery = My.Resources.WinDataMiner.ResourceManager.GetString("qrySQL")
        Dim command As New SqlCommand(selectQuery, connection)
        Dim adapter As New SqlDataAdapter(command)
        Dim dataset As New DataSet

        ' Fill the dataset
        adapter.Fill(dataset)

        Return dataset

    End Function
    ''' <summary>
    ''' Creates a session model that doesn't require admin priveleges on the server
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub DoSessionModel()

        Dim query As String
        Dim connection As AdomdConnection = New AdomdConnection(Me.txtConnectionString.Text)
        Dim command As New AdomdCommand()
        Dim adapter As New AdomdDataAdapter()
        Dim dataset As New DataSet

        Try

            connection.Open()
            ' Drop mining structure if exists from a previous session
            Try
                command.CommandText = "DROP MINING STRUCTURE SessionModel_Structure"
                command.Connection = connection
                command.ExecuteNonQuery()
            Catch ex As Exception
                ' No big deal if we fail; structure simply doesn't exists
            End Try

            ' Create a session model
            query = My.Resources.WinDataMiner.ResourceManager.GetString("qryCreateSession")
            command.CommandText = query

            command.ExecuteNonQuery()

            ' Populate and process the model
            query = My.Resources.WinDataMiner.ResourceManager.GetString("qryInsertSession")
            command.CommandText = query
            command.ExecuteNonQuery()

            ' Predict
            query = txtQuery.Text
            command.CommandText = query
            adapter.SelectCommand = command

            ' Fill the dataset
            adapter.Fill(dataset)

            ' Bind to grid
            dgvResults.DataSource = dataset.Tables(0)
        Catch ex As Exception
            Util.ShowErrorMessage(ex.Message)
        Finally
            ' Close the connection and destroy session
            ' to destroy the session mining model
            connection.Close(True)
        End Try

    End Sub

    ''' <summary>
    ''' Creates a local model that doesn't require admin priveleges on the server
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub DoLocalModel()

        Dim query As String
        Dim connection As AdomdConnection = New AdomdConnection("provider=msolap;data source=c:\LocalCube.cub;Initial Catalog=SOS OLAP")
        Dim command As New AdomdCommand()
        Dim adapter As New AdomdDataAdapter()
        Dim dataset As New DataSet

        Try
            connection.Open()

            ' Drop mining structure if exists from a previous session
            Try
                command.CommandText = "DROP MINING STRUCTURE CustomerClusters_Structure"
                command.Connection = connection
                command.ExecuteNonQuery()
            Catch ex As Exception
                ' No big deal if we fail; structure simply doesn't exists
            End Try

            ' Create a session model
            query = My.Resources.WinDataMiner.ResourceManager.GetString("qryCreateLocal")
            command.Connection = connection
            command.CommandText = query
            command.ExecuteNonQuery()

            ' Populate and process the model
            query = My.Resources.WinDataMiner.ResourceManager.GetString("qryInsertLocal")
            command.CommandText = query
            command.ExecuteNonQuery()

            ' Predict
            query = txtQuery.Text
            command.CommandText = query
            adapter.SelectCommand = command

            ' Fill the dataset
            adapter.Fill(dataset)

            ' Bind to grid
            dgvResults.DataSource = dataset.Tables(0)

        Catch ex As Exception
            Util.ShowErrorMessage(ex.Message)
        Finally
            ' Close the connection and destroy session
            ' to destroy the session mining model
            connection.Close(True)
        End Try

    End Sub

    '/ <summary>
    '/ Gets the user preferences from the isolated storage
    '/ </summary>
    Sub LoadUserSettings()
        Try
            Dim dom As New XmlDocument()
            Dim s As Stream = Util.GetSettingsStream(Me.Name, FileMode.Open, FileAccess.Read, FileShare.Read)
            dom.Load(s)
            txtConnectionString.Text = dom.SelectSingleNode("//connectionString").InnerText
        Catch ' no big deal if we fail - this is a convenience feature only
        End Try
    End Sub 'LoadUserSettings

    '/ <summary>
    '/ Saves the user preferences to the isolated storage
    '/ </summary>
    Sub SaveUserSettings()
        Try
            Dim s As Stream = Util.GetSettingsStream(Me.Name, FileMode.Create, FileAccess.ReadWrite, FileShare.None)
            Dim w As New XmlTextWriter(s, System.Text.Encoding.UTF8)
            w.WriteStartElement(Me.Name)
            w.WriteElementString("connectionString", txtConnectionString.Text)
            w.WriteEndElement()
            w.Close()
        Catch ' no big deal if we fail - this is a convenience feature only
        End Try
    End Sub 'SaveUserSettings

#Region "Events"
    Private Sub Main_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        LoadUserSettings()
    End Sub
    Private Sub Main_Closing(ByVal sender As Object, ByVal e As System.ComponentModel.CancelEventArgs) Handles MyBase.Closing
        SaveUserSettings()
    End Sub


    Private Sub btnSend_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSend.Click
        Try
            Me.Cursor = Cursors.WaitCursor
            If radOpenQuery.Checked Then
                DoOpenQuery()
            ElseIf radSingleton.Checked Then
                DoSingleton()
            ElseIf radRowset.Checked Then
                DoRowset()
            ElseIf radSessionModel.Checked Then
                DoSessionModel()
            ElseIf radLocalModel.Checked Then
                DoLocalModel()
            End If
        Catch ex As Exception
            MessageBox.Show(ex.Message)
            Return
        Finally
            Me.Cursor = Cursors.Default

        End Try
    End Sub


#End Region

 
    Private Sub txtQuery_MouseHover(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles txtQuery.MouseHover
        Me.toolTip.SetToolTip(Me.txtQuery, txtQuery.Text)
        ' make it active so it can show
        Me.toolTip.Active = True
    End Sub



End Class
