Imports System.IO
Imports System.Xml
Imports Microsoft.AnalysisServices.AdomdClient
Public Class Main

    Private m_connection As AdomdConnection

    Private Sub btnConnect_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnConnect.Click
        ClearForm()
        Connect()
        LoadCubes() 'Load cubes
    End Sub
    ''' <summary>
    ''' Connects to the specified SSAS database
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub Connect()
        Me.Cursor = Cursors.WaitCursor
        Try
            Disconnect()

            Try
                m_connection = New AdomdConnection(Me.txtConnectionString.Text)
                m_connection.Open()
            Catch ex As Exception
                MessageBox.Show(ex.Message)
                Return
            End Try
        Finally
            Me.Cursor = Cursors.Default
        End Try
    End Sub 'Connect

    Private Sub LoadCubes()
        Dim cube As CubeDef
        cmbCubes.Items.Clear()
        cmbCubes.Text = String.Empty
        lstKPI.Items.Clear()

        ' Load all cubes in the specified database
        For Each cube In m_connection.Cubes
            If cube.Type = CubeType.Cube Then   ' Skip dimensions
                cmbCubes.Items.Add(cube)
            End If
        Next
        cmbCubes.SelectedIndex = -1

        ' Select the first cube
        If cmbCubes.Items.Count > 0 Then
            cmbCubes.SelectedIndex = 0
        End If

    End Sub
    Private Sub LoadKPIs(ByVal cube As CubeDef)
        Dim kpi As Kpi
        lstKPI.Items.Clear()

        ' Gets the first cube in the database
        For Each kpi In cube.Kpis
            lstKPI.Items.Add(kpi)
        Next

    End Sub
    Private Sub ShowKPIMeta()
        Dim p As Microsoft.AnalysisServices.AdomdClient.Property
        Dim value As String = String.Empty
        Dim kpi As Kpi = CType(lstKPI.SelectedItem, Kpi)
        Dim lsvItem As ListViewItem

        txtCaption.Text = kpi.Caption
        txtDescription.Text = kpi.Description
        txtDisplayFolder.Text = kpi.DisplayFolder
        txtName.Text = kpi.Name
        If kpi.ParentKpi <> Nothing Then
            txtParentKpi.Text = kpi.ParentKpi.Name
        End If
        txtStatusGraphic.Text = kpi.StatusGraphic
        txtTrendGraphic.Text = kpi.TrendGraphic

        For Each p In kpi.Properties
            value = String.Empty
            If p.Value <> Nothing Then
                value = p.Value.ToString()
            End If

            lsvItem = lsvProperties.Items.Add(p.Name)
            lsvItem.SubItems.Add(value)
        Next

    End Sub

    Private Sub ClearForm()
        txtCaption.Clear()
        txtDescription.Clear()
        txtDisplayFolder.Clear()
        txtName.Clear()
        txtStatusGraphic.Clear()
        txtTrendGraphic.Clear()
        lsvProperties.Items.Clear()
    End Sub

    Private Sub Disconnect()
        If Not (m_connection Is Nothing) Then
            m_connection.Dispose()
            m_connection = Nothing
        End If
    End Sub 'Disconnect

    '/ <summary>
    '/ Gets the user preferences from the isolated storage
    '/ </summary>
    Sub LoadUserSettings()
        Try
            Dim dom As New XmlDocument()
            Dim s As Stream = Util.GetSettingsStream(Me.Name, FileMode.Open, FileAccess.Read, FileShare.Read)
            dom.Load(s)
            txtConnectionString.Text = dom.SelectSingleNode("//connectionString").InnerText
        Catch ' no big deal if we fail - this is a convenience feature only
        End Try
    End Sub 'LoadUserSettings

    '/ <summary>
    '/ Saves the user preferences to the isolated storage
    '/ </summary>
    Sub SaveUserSettings()
        Try
            Dim s As Stream = Util.GetSettingsStream(Me.Name, FileMode.Create, FileAccess.ReadWrite, FileShare.None)
            Dim w As New XmlTextWriter(s, System.Text.Encoding.UTF8)
            w.WriteStartElement(Me.Name)
            w.WriteElementString("connectionString", txtConnectionString.Text)
            w.WriteEndElement()
            w.Close()
        Catch ' no big deal if we fail - this is a convenience feature only
        End Try
    End Sub 'SaveUserSettings

#Region "Events"
    Private Sub Main_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        LoadUserSettings()
    End Sub
    Private Sub Main_Closing(ByVal sender As Object, ByVal e As System.ComponentModel.CancelEventArgs) Handles MyBase.Closing
        If Not (m_connection Is Nothing) Then
            If m_connection.State = System.Data.ConnectionState.Open Then
                m_connection.Close()
            End If
        End If
        SaveUserSettings()
    End Sub
    Private Sub txtConnectionString_TextChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles txtConnectionString.TextChanged
        btnConnect.Enabled = txtConnectionString.Text.Trim().Length > 0
    End Sub

    Private Sub lstKPI_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles lstKPI.SelectedIndexChanged
        ClearForm()
        ShowKPIMeta()
    End Sub
    Private Sub cmbCubes_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmbCubes.SelectedIndexChanged
        lstKPI.Items.Clear()
        ClearForm()
        LoadKPIs(CType(cmbCubes.SelectedItem, CubeDef))
    End Sub
#End Region




End Class
